Description Usage Arguments Examples
View source: R/detect_skills.R
Explanation here.
1 | detect_skills(data, id, input, output)
|
data |
A data frame or data frame extension (e.g. a tibble). |
id |
A numeric or character vector unique to each entry. |
input |
Character vector of text data that includes the names of skills you want to detect. |
output |
Output column can be named whatever name you want. |
1 2 3 4 5 6 7 8 9 10 | library(tidyverse)
library(identidy)
data(skills_data)
skills_data <- skills_data %>%
rename(skill_name = skill) %>%
rowid_to_column("rowid")
classified_skills <- skills_data %>%
detect_skills(rowid, skill_name, recoded_skill)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.